% Example how to use multitaper methods for spectrum estimation.
%
% (C) Copyright 2010 
% Mathematical Statistics, Centre for Mathematical Sciences, Lund University, Lund, Sweden
% School of Computing, University of Eastern Finland, Joensuu, Finland

clear all; close all;

%% Read your favorite wave file
[s,fs] = wavread('...');

%% Use VoiceBox's enframing function. Note: ***NO windowing***
framesize   = 240; 
frameshift  = 120;
frames      = enframe(s, framesize, frameshift);

%% Get window functions (note that there's nothing data-dependent here, once
%% you know your frame-length, you can design the window functions off-line.
numwindows = 8;
[thomson_tapers,thomson_weights]      = thomson(framesize, numwindows);
[multipeak_tapers, multipeak_weights] = multipeakwind(framesize, numwindows);
[SWCE_tapers, SWCE_weights]           = SWCE(framesize, numwindows);

%% Compute the spectra using different methods. For comparison, include
%% Hamming method as well.
NFFT = 512;
spec_hamming = multitaperspectra(frames, hamming(framesize), 1, NFFT);
spec_thomson = multitaperspectra(frames, thomson_tapers, thomson_weights, NFFT);
spec_multip  = multitaperspectra(frames, multipeak_tapers, multipeak_weights, NFFT);
spec_SWCE    = multitaperspectra(frames, SWCE_tapers, SWCE_weights, NFFT);

%% Now you have the multitaper power spectra estimates, you can pass them
%% to MFCC computation, plotting, whatever...